==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/messages/cs/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Potvrdit</strong> Akci',
    '<strong>Latest</strong> updates' => '<strong>Poslední</strong> události',
    '<strong>Mail</strong> summary' => '<strong>Mailové</strong> shrnutí',
    'Account settings' => 'Nastavení účtu',
    'Actions' => 'Akce',
    'Administration' => 'Administrace',
    'All' => 'Vše',
    'Allow' => 'Povolit',
    'An error occurred while handling your last action. (Handler not found).' => 'Při manipulaci s vaší poslední akcí došlo k chybě. (Handler nebyl nalezen).',
    'An unexpected error occurred while loading the search result.' => 'Během načítání výsledku vyhledávání došlo k neočekávané chybě.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Vyskytla se neočekávaná chyba. Pokud chyba stále přetrvává, obraťte se na správce webu.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Došlo k neočekávané chybě serveru. Pokud chyba stále přetrvává, obraťte se na správce webu.',
    'An unknown error occurred while uploading.' => 'Během nahrávání došlo k neznámé chybě.',
    'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Během nahrávání došlo k neznámé chybě. Tip: zkontrolujte nastavení php upload_max_filesize a post_max_size.',
    'Back' => 'Zpět',
    'Back to dashboard' => 'Zpět na nástěnku',
    'Cancel' => 'Zrušit',
    'Choose language:' => 'Vyberte jazyk:',
    'Close' => 'Zavřít',
    'Collapse' => 'Sbalit',
    'Confirm' => 'Potvrdit',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Content Addon musí být buď instancí objektu HActiveRecordContent nebo HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Kopírovat do schránky',
    'Could not find content of addon!' => 'Nebylo možné nalézt obsah dolpňku!',
    'Default' => 'Výchozí',
    'Delete' => 'Smazat',
    'Deny' => 'Odmítnout',
    'Do you really want to perform this action?' => 'Opravdu chcete tuto akci provést?',
    'Edit' => 'Upravit',
    'Error' => 'Chyba',
    'Error while running your last action (Invalid request method).' => 'Při spuštění poslední akce došlo k chybě (metoda neplatného požadavku).',
    'Error:' => 'Chyba:',
    'Expand' => 'Rozbalit',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Neplatná metoda požadavku!',
    'It looks like you may have taken the wrong turn.' => 'Zdá se, že jste někde špatně odbočili.',
    'Language' => 'Jazyk',
    'Loading...' => 'Načítání....',
    'Login' => 'Přihlásit se',
    'Logo of {appName}' => 'Logo aplikace',
    'Logout' => 'Odhlásit',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'Modul nebyl nalezen nebo je vypnut!',
    'My profile' => 'Můj profil',
    'New profile image' => 'Nový profilový obrázek',
    'Next' => 'Další',
    'No error information given.' => 'Nejsou uvedeny žádné informace o chybách.',
    'Oooops...' => 'Jejda...',
    'Open' => 'Otevřít',
    'Please type at least 3 characters' => 'Napište prosím alespoň 3 znaky',
    'Profile dropdown' => 'Menu profilu',
    'Profile picture of {displayName}' => 'Profilový obrázek',
    'Save' => 'Uložit',
    'Saved' => 'Uloženo',
    'Search' => 'Hledat',
    'Show less' => 'Zobrazit méně',
    'Show more' => 'Zobrazit více',
    'Some files could not be uploaded:' => 'Některé soubory nelze nahrát:',
    'The date has to be in the past.' => 'Datum musí být v minulosti.',
    'The file has been deleted.' => 'Tento soubor byl vymazán.',
    'The requested resource could not be found.' => 'Požadovaný zdroj nebyl nalezen.',
    'The space has been archived.' => 'Prostor byl archivován.',
    'The space has been unarchived.' => 'Prostor byl zrušen.',
    'Toggle comment menu' => 'Přepnout menu komentářů',
    'Toggle panel menu' => 'Přepnout menu panelu',
    'Toggle post menu' => 'Přepnout menu příspěvků',
    'Toggle stream entry menu' => 'Přepnout menu vláken',
    'Unsubscribe' => 'Odhlásit odběr',
    'Upload' => 'Nahrát',
    'Upload file' => 'Nahrát soubor',
    'You are not allowed to run this action.' => 'Nemáte povolení spustit tuto akci.',
    'Add:' => '',
    'Could not find requested page.' => '',
    'Export' => '',
    'Please type at least {count} characters' => '',
    'Powered by {name}' => '',
    'Select Me' => '',
    'Stop impersonation' => '',
    'Text could not be copied to clipboard' => '',
    'Text has been copied to clipboard' => '',
    'Time Zone' => '',
    'Unsaved changes will be lost. Do you want to proceed?' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/messages/cs/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Potvrdit</strong> akci',
    '<strong>Latest</strong> updates' => '<strong>Nejnovější</strong> události',
    '<strong>Mail</strong> summary' => '<strong>Mailové</strong> shrnutí',
    'Account settings' => 'Nastavení účtu',
    'Actions' => 'Akce',
    'Administration' => 'Administrace',
    'All' => 'Vše',
    'Allow' => 'Povolit',
    'An error occurred while handling your last action. (Handler not found).' => 'Při manipulaci s vaší poslední akcí došlo k chybě. (Handler nebyl nalezen).',
    'An unexpected error occurred while loading the search result.' => 'Během načítání výsledku vyhledávání došlo k neočekávané chybě.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Vyskytla se neočekávaná chyba. Pokud chyba stále přetrvává, obraťte se na správce webu.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Došlo k neočekávané chybě serveru. Pokud chyba stále přetrvává, obraťte se na správce webu.',
    'An unknown error occurred while uploading.' => 'Během nahrávání došlo k neznámé chybě.',
    'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Během nahrávání došlo k neznámé chybě. Tip: zkontrolujte nastavení php upload_max_filesize a post_max_size.',
    'Back' => 'Zpět',
    'Back to dashboard' => 'Zpět na nástěnku',
    'Cancel' => 'Zrušit',
    'Choose language:' => 'Vyberte jazyk:',
    'Close' => 'Zavřít',
    'Collapse' => 'Sbalit',
    'Confirm' => 'Potvrdit',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Content Addon musí být buď instancí objektu HActiveRecordContent nebo HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Kopírovat do schránky',
    'Could not find content of addon!' => 'Nebylo možné nalézt obsah dolpňku!',
    'Default' => 'Výchozí',
    'Delete' => 'Smazat',
    'Deny' => 'Odmítnout',
    'Do you really want to perform this action?' => 'Opravdu chcete tuto akci provést?',
    'Edit' => 'Upravit',
    'Error' => 'Chyba',
    'Error while running your last action (Invalid request method).' => 'Při spuštění poslední akce došlo k chybě (metoda neplatného požadavku).',
    'Error:' => 'Chyba:',
    'Expand' => 'Rozbalit',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Neplatná metoda požadavku!',
    'It looks like you may have taken the wrong turn.' => 'Zdá se, že jste někde špatně odbočili.',
    'Language' => 'Jazyk',
    'Loading...' => 'Načítání....',
    'Login' => 'Přihlásit se',
    'Logo of {appName}' => 'Logo aplikace',
    'Logout' => 'Odhlásit',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'Modul nebyl nalezen nebo je vypnut!',
    'My profile' => 'Můj profil',
    'New profile image' => 'Nový profilový obrázek',
    'Next' => 'Další',
    'No error information given.' => 'Nejsou uvedeny žádné informace o chybách.',
    'Oooops...' => 'Jejda...',
    'Open' => 'Otevřít',
    'Please type at least 3 characters' => 'Napište prosím alespoň 3 znaky',
    'Profile dropdown' => 'Menu profilu',
    'Profile picture of {displayName}' => 'Profilový obrázek',
    'Save' => 'Uložit',
    'Saved' => 'Uloženo',
    'Search' => 'Hledat',
    'Show less' => 'Zobrazit méně',
    'Show more' => 'Zobrazit více',
    'Some files could not be uploaded:' => 'Některé soubory nelze nahrát:',
    'The date has to be in the past.' => 'Datum musí být v minulosti.',
    'The file has been deleted.' => 'Tento soubor byl vymazán.',
    'The requested resource could not be found.' => 'Požadovaný zdroj nebyl nalezen.',
    'The space has been archived.' => 'Prostor byl archivován.',
    'The space has been unarchived.' => 'Prostor byl zrušen.',
    'Time Zone' => 'Časové pásmo',
    'Toggle comment menu' => 'Přepnout menu komentářů',
    'Toggle panel menu' => 'Přepnout menu panelu',
    'Toggle post menu' => 'Přepnout menu příspěvků',
    'Toggle stream entry menu' => 'Přepnout menu vláken',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Neuložené změny budou ztraceny. Chcete pokračovat?',
    'Unsubscribe' => 'Odhlásit odběr',
    'Upload' => 'Nahrát',
    'Upload file' => 'Nahrát soubor',
    'You are not allowed to run this action.' => 'Nemáte povolení spustit tuto akci.',
    'Add:' => '',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'Could not find requested page.' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'Export' => '',
    'Please type at least {count} characters' => '',
    'Powered by {name}' => '',
    'Select Me' => '',
    'Stop impersonation' => '',
    'Text could not be copied to clipboard' => '',
    'Text has been copied to clipboard' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];
